# SimpactCyan HIV
[SimpactCyan](https://simpactcyan.readthedocs.io/en/latest/simpact_introduction.html)
is an agent-based simulator used in HIV epidemiology. The model was designed to
simulate and study the transmission, treatment and prevention of HIV infections
in dynamic social networks. For instance, in the paper originally introducing
the software, the authors estimate the impact of progressive changes to the
eligibility criteria for HIV treatment on HIV incidence. 

For detailed installation instructions, see:
```
https://github.com/j0r1/simpactcyan
```

TODO: Understand this simulator and implement experiments on top of it.
